#!/bin/sh
# term_display - run a command in a new xterm.

myname=`basename $0`
usage () {
echo "
Usage: $myname {USE_MORE | NO_MORE} command-invocation
       USE_MORE: to pipe output through 'more'
       NO_MORE:  display output directly

The EV ATRIA_TERM_INTRO can be set to provide a message
before running the command, e.g.
    Finding ...
"
    exit 1
}

trap 'rm -f /tmp/termdisp.$$; exit 1' 1 2 3 9 15

rm -f /tmp/termdisp.$$

if [ "$1" = "USE_MORE" ] ; then
    USE_MORE=1
elif [ "$1" = "NO_MORE" ] ; then
    USE_MORE=0
else
    echo "$0 usage error, 1st arg should be USE_MORE or NO_MORE"
    exit 1
fi
shift

#------------- Script run by xterm -------------

cat <<! >/tmp/termdisp.$$
#!/bin/sh
trap 'sleep 1; echo 1>&2; echo "Type <CR> to exit" 1>&2; read xxx; exit 1' 1 2 3 9 15

# RATLC01091113 - AIX has a problem with passing the $NLSPATH environment
# variable to the dtterm in which the command is run. Setting it explicitly
# to ensure we have the right value for $NLSPATH.
# Note that that NLSPATH gets expanded prior to generating the command to
# set NLSPATH.  The new shell doesn't inherit the value for NLSPATH and it
# needs to be set explicitly.

NLSPATH=$NLSPATH
export NLSPATH

# SGI xwsh doesn't inherit stty settings (without .wshttymodestty)
# so you can't quit out of commands. We compensate by setting 'intr' to ^C
#
if [ "$XC_EXEC_NAME" = "xwsh" ] ; then
    if [ ! -r $HOME/.wshttymodestty ] ; then
	stty intr '^C' 2>/dev/null
    fi
fi

if [ "$ATRIA_TERM_INTRO" != "" ] ; then
    echo "$ATRIA_TERM_INTRO"
    echo
fi

if [ $USE_MORE = 1 ] ; then
    $* 2>&1 | more
else
    $*
fi

echo
echo "Type <CR> to exit"
read xxx
!

#-----------------------------------------------

chmod +x /tmp/termdisp.$$
if [ "$ATRIA_DEBUG_BUTTON" != "" ] ; then
    echo "-------------------"
    echo "/tmp/termdisp.$$"
    cat /tmp/termdisp.$$
    echo "-------------------"
else
    if [ "$XC_SCROLLBAR_FLAG" != "" ] ; then
        MORE_XC_ARGS="$XC_SCROLLBAR_FLAG"
        if [ "$XC_SCROLLBAR_ARG" != "" ] ; then
            MORE_XC_ARGS="$MORE_XC_ARGS $XC_SCROLLBAR_ARG"
        fi
    fi
    if [ "$XC_SAVE_LINES_FLAG" != "" ] ; then
        MORE_XC_ARGS="$MORE_XC_ARGS $XC_SAVE_LINES_FLAG 500"
    fi
#
# Japanese terminal support
#
    if [ "$LANG" != "" -a "$XC_EXEC_NAME" = "xterm" ]; then
	LANG_PREFIX=`echo $LANG | cut -c 1,2 | tr '[A-Z]' '[a-z]'`
	if [ "$LANG_PREFIX" = "ja" -o "$LANG_PREFIX" = "jp" ]; then
	    # find kanji terminal command
	    kanji_term_cmd=`type gnome-terminal 2> /dev/null | awk '{ print $NF }'`
	    if [ "$kanji_term_cmd" != "" ]; then
		TERM_FLAG="--disable-factory"
		MORE_XC_ARGS=""
	    else
		kanji_term_cmd=`type aterm 2> /dev/null | awk '{ print $NF }'`	    
		if [ "$kanji_term_cmd" = "" ]; then
		    kanji_term_cmd=`type kterm 2> /dev/null | awk '{ print $NF }'`
		    LANG_SUFFIX=`echo $LANG | cut -c 7,8,9,10| tr '[A-Z]' '[a-z]'`
		    ORIG_LANG_PREFIX=`echo $LANG | cut -c 1,2`
		    if [ "$LANG_SUFFIX" = "sjis" -o "$ORIG_LANG_PREFIX" = "Ja" ]; then
			TERM_FLAG="-km sjis"
		    else
			TERM_FLAG="-km euc"
		    fi
		fi
	    fi
	    if [ "$kanji_term_cmd" != "" ]; then
		XC_EXEC_PNAME=$kanji_term_cmd; export XC_EXEC_PNAME
	    else
		TERM_FLAG=""
	    fi
	fi
    fi
    if [ $XC_EXEC_NAME = "cmdtool" ] ; then
	# need an extra 'exit' because cmdtool runs a shell
	($XC_EXEC_PNAME $TERM_FLAG $MORE_XC_ARGS $XC_COMMAND_FLAG "/tmp/termdisp.$$;exit" ; rm -f /tmp/termdisp.$$) &
    else
	# xterm and xwsh just run argument -- no extra shell
	($XC_EXEC_PNAME $TERM_FLAG $MORE_XC_ARGS $XC_COMMAND_FLAG /tmp/termdisp.$$ ; rm -f /tmp/termdisp.$$) &
    fi
fi





